@@ -69,8 +69,8 @@ DiseasystoreBase <- R6::R6Class(
 
 
       # Check source and target conn has been set correctly
-      if (is.null(self %.% source_conn)) stop("source_conn option not defined for ", class(self)[1])
-      if (is.null(self %.% target_conn)) stop("target_conn option not defined for ", class(self)[1])
+      if (is.null(self %.% source_conn)) stop("source_conn option not defined for ", class(self)[1], call. = FALSE)
+      if (is.null(self %.% target_conn)) stop("target_conn option not defined for ", class(self)[1], call. = FALSE)
       checkmate::assert_class(self %.% target_conn, "DBIConnection")
 
 
@@ -87,16 +87,6 @@ DiseasystoreBase <- R6::R6Class(
     },
 
 
-    #' @description
-    #'   Closes the open DB connection when removing the object
-    finalize = function() {
-      purrr::walk(list(self %.% target_conn, self %.% source_conn),
-                  ~ if (inherits(., "DBIConnection") && !inherits(., "TestConnection") && DBI::dbIsValid(.)) {
-                    DBI::dbDisconnect(., shutdown = TRUE)
-                  })
-    },
-
-
     #' @description
     #'   Computes, stores, and returns the requested feature for the study period.
     #' @param feature (`character`)\cr
@@ -161,7 +151,10 @@ DiseasystoreBase <- R6::R6Class(
           Sys.sleep(diseasyoption("lock_wait_increment", self))
           wait_time <- wait_time + diseasyoption("lock_wait_increment", self)
           if (wait_time > diseasyoption("lock_wait_max", self)) {
-            stop(glue::glue("Lock not released within {diseasyoption('lock_wait_max', self)/60} minutes. Giving up."))
+            stop(
+              glue::glue("Lock not released within {diseasyoption('lock_wait_max', self)/60} minutes. Giving up."),
+              call. = FALSE
+            )
           }
         }
 
@@ -191,9 +184,11 @@ DiseasystoreBase <- R6::R6Class(
 
           # Check it table is copied to target DB
           if (!inherits(ds_feature, "tbl_dbi") || !identical(self %.% source_conn, self %.% target_conn)) {
-            ds_feature <- ds_feature |>
-              dplyr::copy_to(self %.% target_conn, df = _,
-                             name = paste("ds", feature_loader, Sys.getpid(), sep = "_"))
+            ds_feature <- dplyr::copy_to(
+              self %.% target_conn,
+              df = ds_feature,
+              name = SCDB::unique_table_name(paste0("ds_", feature_loader))
+            )
             SCDB::defer_db_cleanup(ds_feature)
           }
 
@@ -208,7 +203,9 @@ DiseasystoreBase <- R6::R6Class(
                 dplyr::filter(.data$valid_until <= start_date, .data$valid_from < end_date)
             }
 
-            ds_updated_feature <- dplyr::union_all(ds_existing, ds_feature) |> dplyr::compute()
+            ds_updated_feature <- dplyr::union_all(ds_existing, ds_feature) |>
+              dplyr::compute(name = SCDB::unique_table_name("ds_updated_feature"))
+            SCDB::defer_db_cleanup(ds_updated_feature)
           } else {
             ds_updated_feature <- ds_feature
           }
@@ -258,8 +255,11 @@ DiseasystoreBase <- R6::R6Class(
 
       # We need to slice to the period of interest.
       # to ensure proper conversion of variables, we first copy the limits over and then do an inner_join
-      validities <- data.frame(valid_from = start_date, valid_until = end_date) |>
-        dplyr::copy_to(self %.% target_conn, df = _, name = paste0("ds_validities_", Sys.getpid()))
+      validities <- dplyr::copy_to(
+        self %.% target_conn,
+        df = data.frame(valid_from = start_date, valid_until = end_date),
+        name = SCDB::unique_table_name("ds_validities")
+      )
       SCDB::defer_db_cleanup(validities)
 
       out <- dplyr::inner_join(out, validities,
@@ -267,21 +267,16 @@ DiseasystoreBase <- R6::R6Class(
                                          ("LHS"."valid_until" > "RHS"."valid_from" OR "LHS"."valid_until" IS NULL)',
                                suffix = c("", ".p")) |>
         dplyr::select(!c("valid_from.p", "valid_until.p")) |>
-        dplyr::compute()
+        dplyr::compute(name = SCDB::unique_table_name("ds_get_feature"))
 
       return(out)
     },
 
     #' @description
-    #'   Joins various features from feature store assuming a primary feature (observable)
-    #'   that contains keys to witch the secondary features (defined by `stratification`) can be joined.
-    #' @param observable (`character`)\cr
-    #'   The name of a feature defined in the feature store
-    #' @param stratification (`list`(`quosures`) or `NULL`)\cr
-    #'   Expressions in `stratification` are evaluated to find appropriate features.
-    #'   These are then joined to the observable feature before `stratification` is performed.
-    #'
-    #'   If `NULL` (default) no stratification is performed.
+    #'   Joins various features from the feature store assuming a primary feature (observable)
+    #'   that contains keys to witch the secondary features (defined by `stratification`) are joined.
+    #' @param observable `r rd_observable()`
+    #' @param stratification `r rd_stratification()`
     #' @param start_date `r rd_start_date()`
     #' @param end_date `r rd_end_date()`
     #' @return
@@ -293,11 +288,7 @@ DiseasystoreBase <- R6::R6Class(
 
       coll <- checkmate::makeAssertCollection()
       checkmate::assert_choice(observable, self$available_observables, add = coll)
-      checkmate::assert(
-        checkmate::check_list(stratification, types = "character", null.ok = TRUE),
-        checkmate::check_multi_class(stratification, c("character", "quosure", "quosures"), null.ok = TRUE),
-        add = coll
-      )
+      checkmate::assert_multi_class(stratification, c("quosure", "quosures"), null.ok = TRUE, add = coll)
       checkmate::assert_date(start_date, add = coll)
       checkmate::assert_date(end_date, add = coll)
       checkmate::reportAssertions(coll)
@@ -306,13 +297,19 @@ DiseasystoreBase <- R6::R6Class(
       ds_map <- self %.% ds_map
 
       # We start by copying the study_dates to the conn to ensure SQLite compatibility
-      study_dates <- data.frame(valid_from = start_date, valid_until = base::as.Date(end_date + lubridate::days(1))) |>
-        dplyr::copy_to(self %.% target_conn, df = _, name = paste0("ds_study_dates_", Sys.getpid()))
+      study_dates <- dplyr::copy_to(
+        self %.% target_conn,
+        df = data.frame(valid_from = start_date, valid_until = base::as.Date(end_date + lubridate::days(1))),
+        name = SCDB::unique_table_name("ds_study_dates")
+      )
       SCDB::defer_db_cleanup(study_dates)
 
       # Fetch the requested observable from the feature store and truncate to the start and end dates
       # to simplify the interlaced output
-      observable_data <- self$get_feature(observable, start_date, end_date) |>
+      observable_data <- self$get_feature(observable, start_date, end_date)
+      SCDB::defer_db_cleanup(observable_data)
+
+      observable_data <- observable_data |>
         dplyr::cross_join(study_dates, suffix = c("", ".d")) |>
         dplyr::mutate(
           "valid_from" = ifelse(.data$valid_from >= .data$valid_from.d, .data$valid_from, .data$valid_from.d),          # nolint: ifelse_censor_linter
@@ -324,7 +321,7 @@ DiseasystoreBase <- R6::R6Class(
         dplyr::select(!ends_with(".d"))
 
       # Determine the keys
-      observable_keys  <- colnames(dplyr::select(observable_data, tidyselect::starts_with("key_")))
+      observable_keys <- colnames(dplyr::select(observable_data, tidyselect::starts_with("key_")))
 
       # Give warning if stratification features are already in the observables data
       # First we identify the computations being done in the stratifications, only stratifications that compute a new
@@ -338,13 +335,24 @@ DiseasystoreBase <- R6::R6Class(
       # .. and then we look for overlap with existing stratifications
       existing_stratification <- intersect(colnames(observable_data), new_stratifications)
       if (length(existing_stratification) > 0) {
-        warning("Observable already stratified by: ", toString(existing_stratification), ". ",
-                "Output might be inconsistent with expectation.")
+        warning(
+          "Observable already stratified by: ",
+          toString(existing_stratification), ". ",
+          "Output might be inconsistent with expectation.",
+          call. = FALSE
+        )
       }
 
 
       # Determine which features are affected by a stratification
-      if (!is.null(stratification)) {
+      if (is.null(stratification)) {
+
+        stratification_features <- NULL
+        stratification_names <- NULL
+        stratification_data <- NULL
+        out <- observable_data
+
+      } else {
 
         # Create regex detection for features
         ds_map_regex <- paste0(r"{(?<=^|\W)}", names(ds_map), r"{(?=$|\W)}")
@@ -359,14 +367,6 @@ DiseasystoreBase <- R6::R6Class(
           unlist() |>
           unique()
 
-        # Report if stratification not found
-        if (is.null(stratification_features)) {
-          err <- glue::glue("Stratification variable not found. ",
-                            "Available stratification variables are: ",
-                            "{toString(self$available_stratifications)}")
-          stop(err)
-        }
-
         # Determine the name of the columns created by the stratifications
         stratification_names <- stratification |>
           purrr::map(rlang::as_label) |>
@@ -381,35 +381,46 @@ DiseasystoreBase <- R6::R6Class(
         stratification_data <- stratification_features |>
           purrr::discard(~ . %in% colnames(observable_data)) |> # Skip those already in the observable data
           unique() |>
-          purrr::map(~ {
-            # Fetch the requested stratification feature from the feature store and truncate to the start
-            #  and end dates to simplify the interlaced output
-            self$get_feature(.x, start_date, end_date) |>
-              dplyr::cross_join(study_dates, suffix = c("", ".d")) |>
-              dplyr::mutate(
-                "valid_from" = ifelse(.data$valid_from >= .data$valid_from.d, .data$valid_from, .data$valid_from.d),    # nolint: ifelse_censor_linter
-                "valid_until" = dplyr::coalesce(
-                  ifelse(.data$valid_until <= .data$valid_until.d, .data$valid_until, .data$valid_until.d),             # nolint: ifelse_censor_linter
-                  .data$valid_until.d
-                )
-              ) |>
-              dplyr::select(!ends_with(".d"))
-          })
+          purrr::map(~ self$get_feature(.x, start_date, end_date))
 
         # Check if no stratification data was pulled
-        if (length(stratification_data) == 0) stratification_data <- NULL
+        if (length(stratification_data) == 0) {
 
-      } else {
-        stratification_features <- NULL
-        stratification_names <- NULL
-        stratification_data <- NULL
+          stratification_data <- NULL
+          out <- observable_data
+
+        } else {
+
+          # Pre-truncate stratification data to the start and end dates to simplify the interlaced output
+          stratification_data_truncated <- stratification_data |>
+            purrr::map(\(feature) {
+              feature |>
+                dplyr::cross_join(study_dates, suffix = c("", ".d")) |>
+                dplyr::mutate(
+                  "valid_from" = ifelse(.data$valid_from >= .data$valid_from.d, .data$valid_from, .data$valid_from.d),  # nolint: ifelse_censor_linter
+                  "valid_until" = dplyr::coalesce(
+                    ifelse(.data$valid_until <= .data$valid_until.d, .data$valid_until, .data$valid_until.d),           # nolint: ifelse_censor_linter
+                    .data$valid_until.d
+                  )
+                ) |>
+                dplyr::select(!ends_with(".d"))
+            })
+
+          # Merge stratifications to the observables
+          out <- truncate_interlace(observable_data, stratification_data_truncated)
+          if (length(stratification_data_truncated) == 1) {
+            out <- dplyr::compute(out, name = SCDB::unique_table_name("ds_truncate_interlace"))
+          }
+          SCDB::defer_db_cleanup(out)
+
+          # Stratification data is no longer needed
+          purrr::walk(stratification_data, SCDB::defer_db_cleanup)
+        }
       }
 
 
-      # Merge and prepare for counting
-      out <- truncate_interlace(observable_data, stratification_data) |>
-        private$key_join_filter(stratification_features, start_date, end_date) |>
-        dplyr::compute()
+      # Run the filtering needed for semi-aggregated data
+      out <- private$key_join_filter(out, stratification_features, start_date, end_date)
 
       # Retrieve the aggregators (and ensure they work together)
       key_join_aggregators <- c(purrr::pluck(private, purrr::pluck(ds_map, observable)) %.% key_join,
@@ -417,46 +428,61 @@ DiseasystoreBase <- R6::R6Class(
                                            ~ purrr::pluck(private, purrr::pluck(ds_map, .x)) %.% key_join))
 
       if (length(unique(key_join_aggregators)) > 1) {
-        stop("(At least one) stratification feature does not match observable aggregator. Not implemented yet.")
+        stop(
+          "(At least one) stratification feature does not match observable aggregator. Not implemented yet.",
+          call. = FALSE
+        )
       }
 
       key_join_aggregator <- purrr::pluck(key_join_aggregators, 1)
 
+      # Check stratification can be performed:
+      out <- tryCatch(
+        dplyr::group_by(out, !!!stratification),
+        error = function(e) {
+          error_msg <- glue::glue(
+            "Stratification could not be computed. ",
+            "Error {tolower(substr(e$message, 1, 1))}{substr(e$message, 2, nchar(e$message))}. ",
+            "Available stratification variables are: ",
+            "{toString(self$available_stratifications)}"
+          )
+          stop(error_msg, call. = FALSE)
+        }
+      )
+
       # Add the new valid counts
       t_add <- out |>
-        dplyr::group_by(!!!stratification) |>
         dplyr::group_by("date" = .data$valid_from, .add = TRUE) |>
         key_join_aggregator(observable) |>
         dplyr::rename("n_add" = "n") |>
-        dplyr::compute()
+        dplyr::compute(name = SCDB::unique_table_name("ds_add"))
+      SCDB::defer_db_cleanup(t_add)
 
       # Add the new invalid counts
       t_remove <- out |>
-        dplyr::group_by(!!!stratification) |>
         dplyr::group_by("date" = .data$valid_until, .add = TRUE) |>
         key_join_aggregator(observable) |>
         dplyr::rename("n_remove" = "n") |>
-        dplyr::compute()
+        dplyr::compute(name = SCDB::unique_table_name("ds_remove"))
+      SCDB::defer_db_cleanup(t_remove)
 
       # Get all combinations to merge onto
-      all_dates <- tibble::tibble(date = seq.Date(from = start_date, to = end_date, by = 1))
+      all_dates <- dplyr::copy_to(
+        self %.% target_conn,
+        df = tibble::tibble(date = seq.Date(from = start_date, to = end_date, by = 1)),
+        name = SCDB::unique_table_name("ds_all_dates")
+      )
+      SCDB::defer_db_cleanup(all_dates)
 
-      if (!is.null(stratification)) {
-        all_combinations <- out |>
-          dplyr::ungroup() |>
-          dplyr::distinct(!!!stratification) |>
-          dplyr::cross_join(all_dates, copy = TRUE) |>
-          dplyr::compute()
-      } else {
+      if (is.null(stratification)) {
         all_combinations <- all_dates
-
-        # Copy if needed
-        if (is.null(stratification)) {
-          all_combinations <- all_combinations |>
-            dplyr::copy_to(self %.% target_conn, df = _,
-                           name = paste0("ds_all_combinations_", Sys.getpid()))
-          SCDB::defer_db_cleanup(all_combinations)
-        }
+      } else {
+        all_combinations <- out |>
+          dplyr::select(dplyr::all_of(stratification_names)) |>
+          dplyr::distinct() |>
+          dplyr::cross_join(all_dates) |>
+          dplyr::compute(name = SCDB::unique_table_name("ds_all_combinations"))
+        SCDB::defer_db_cleanup(all_combinations)
       }
 
       # Aggregate across dates
@@ -475,12 +501,6 @@ DiseasystoreBase <- R6::R6Class(
       data <- data |>
         dplyr::mutate("date" = as.Date(.data$date))
 
-
-      # Clean up
-      DBI::dbRemoveTable(self %.% target_conn, SCDB::id(out))
-      DBI::dbRemoveTable(self %.% target_conn, SCDB::id(t_add))
-      DBI::dbRemoveTable(self %.% target_conn, SCDB::id(t_remove))
-
       return(data)
     }
   ),
@@ -505,7 +525,7 @@ DiseasystoreBase <- R6::R6Class(
     ),
 
 
-    #' @field available_features (`character`)\cr
+    #' @field available_features (`character()`)\cr
     #'   A list of available features in the feature store. Read only.
     available_features = purrr::partial(
       .f = active_binding,
@@ -514,25 +534,34 @@ DiseasystoreBase <- R6::R6Class(
     ),
 
 
-    #' @field available_observables (`character`)\cr
+    #' @field available_observables (`character()`)\cr
     #'   A list of available observables in the feature store. Read only.
     available_observables = purrr::partial(
       .f = active_binding,
       name = "available_observables",
-      expr = return(purrr::keep(self$available_features, ~ stringr::str_detect(., private$.observables_regex)))
+      expr = return(purrr::keep(self$available_features, ~ stringr::str_detect(., self$observables_regex)))
     ),
 
 
-    #' @field available_stratifications (`character`)\cr
+    #' @field available_stratifications (`character()`)\cr
     #'   A list of available stratifications in the feature store. Read only.
     available_stratifications = purrr::partial(
       .f = active_binding,
       name = "available_stratifications",
-      expr = return(purrr::discard(self$available_features, ~ stringr::str_detect(., private$.observables_regex)))
+      expr = return(purrr::discard(self$available_features, ~ stringr::str_detect(., self$observables_regex)))
     ),
 
 
-    #' @field label (`character`)\cr
+    #' @field observables_regex (`character(1)`)\cr
+    #'   A list of available stratifications in the feature store. Read only.
+    observables_regex = purrr::partial(
+      .f = active_binding,
+      name = "observables_regex",
+      expr = return(private$.observables_regex)
+    ),
+
+
+    #' @field label (`character(1)`)\cr
     #'   A human readable label of the feature store. Read only.
     label = purrr::partial(
       .f = active_binding,
@@ -643,7 +672,6 @@ DiseasystoreBase <- R6::R6Class(
     # @param slice_ts `r rd_slice_ts()`
     # @return (`tibble`)\cr
     #   A data frame containing continuous un-computed date-ranges
-    #' @importFrom zoo as.Date
     determine_new_ranges = function(target_table, start_date, end_date, slice_ts) {
 
       # Get a list of the logs for the target_table on the slice_ts
@@ -693,10 +721,8 @@ DiseasystoreBase <- R6::R6Class(
       new_interval <- seq.Date(from = base::as.Date(start_date), to = base::as.Date(end_date), by = "1 day")
 
       # Determine the dates that needs to be computed
-      new_dates <- zoo::as.Date(setdiff(new_interval, ds_dates))
+      new_dates <- as.Date(setdiff(new_interval, ds_dates))
       # setdiff does not preserve type (converts from Date to numeric)
-      # it even breaks the type so hard, that we need to supply the origin also (which for some reason is not default)
-      # so we use the zoo::as.Date, since this is reasonably configured...
 
       # Early return, if no new dates are found
       if (length(new_dates) == 0) {
@@ -736,6 +762,17 @@ DiseasystoreBase <- R6::R6Class(
                                start_date = self %.% start_date,
                                end_date   = self %.% end_date) {
       return(.data) # By default, no filtering is performed
+    },
+
+
+    # @description
+    #   Closes the open DB connection when removing the object
+    finalize = function() {
+      list(self %.% target_conn, self %.% source_conn) |>
+        purrr::keep(~ inherits(., "DBIConnection")) |>
+        purrr::discard(~ inherits(., "TestConnection")) |>
+        purrr::keep(~ DBI::dbIsValid(.)) |>
+        purrr::walk(DBI::dbDisconnect)
     }
   )
 )
