@@ -36,17 +36,17 @@ get_test_conns <- function(skip_backends = NULL) {
   } else {
 
     # Use the connection configured by the remote
-    conn_list <- tibble::lst(!!Sys.getenv("BACKEND") := !!Sys.getenv("BACKEND_DRV"))                                    # nolint: object_name_linter
+    conn_list <- tibble::lst(!!Sys.getenv("BACKEND") := !!Sys.getenv("BACKEND_DRV"))
 
     # Use the connection configured by the remote
-    conn_args <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_ARGS")) |>                                  # nolint: object_name_linter
-      purrr::discard(~ identical(., "")) |>
-      purrr::map(~ eval(parse(text = .)))
+    conn_args <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_ARGS"))
+    conn_args <- purrr::discard(conn_args, ~ identical(., ""))
+    conn_args <- purrr::map(conn_args, ~ eval(parse(text = .)))
 
     # Use the connection configured by the remote
-    conn_post_connect <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_POST_CONNECT")) |>                  # nolint: object_name_linter
-      purrr::discard(~ identical(., "")) |>
-      purrr::map(~ eval(parse(text = .)))
+    conn_post_connect <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_POST_CONNECT"))
+    conn_post_connect <- purrr::discard(conn_post_connect, ~ identical(., ""))
+    conn_post_connect <- purrr::map(conn_post_connect, ~ eval(parse(text = .)))
 
   }
 
@@ -60,14 +60,19 @@ get_test_conns <- function(skip_backends = NULL) {
 
   # Combine all arguments
   backends <- unique(c(names(conn_list), names(conn_args), names(conn_args_json)))
-  conn_args <- backends |>
-    purrr::map(~ c(purrr::pluck(conn_args, .), purrr::pluck(conn_args_json, .))) |>
-    stats::setNames(backends)
+  conn_args <- purrr::map(backends, ~ c(purrr::pluck(conn_args, .), purrr::pluck(conn_args_json, .)))
+  names(conn_args) <- backends
 
 
   get_driver <- function(x = character(), ...) {                                                                        # nolint: object_usage_linter
-    if (!grepl(".*::.*", x)) stop("Package must be specified with namespace (e.g. RSQLite::SQLite)!\n",
-                                  "Received: ", x)
+    if (!grepl(".*::.*", x)) {
+      stop(
+        "Package must be specified with namespace (e.g. RSQLite::SQLite)!\n",
+        "Received: ",
+        x,
+        call. = FALSE
+      )
+    }
     parts <- strsplit(x, "::", fixed = TRUE)[[1]]
 
     # Skip unavailable packages
@@ -83,28 +88,43 @@ get_test_conns <- function(skip_backends = NULL) {
   checkmate::assert_subset(names(conn_args), names(conn_list))
 
   # Open connections
-  drivers <- names(conn_list) |>
-    purrr::map(~ do.call(get_driver, list(x = purrr::pluck(conn_list, .)))) |>
-    stats::setNames(names(conn_list)) |>
-    purrr::discard(is.null)
+  drivers <- purrr::map(names(conn_list), ~ do.call(get_driver, list(x = purrr::pluck(conn_list, .))))
+  names(drivers) <- names(conn_list)
+  drivers <- purrr::discard(drivers, is.null)
 
-  test_conns <- names(drivers) |>
-    purrr::map(~ do.call(SCDB::get_connection, c(list(drv = purrr::pluck(drivers, .)), purrr::pluck(conn_args, .)))) |>
-    stats::setNames(names(drivers)) |>
-    purrr::discard(is.null)
+  test_conn_args <- purrr::map(
+    names(drivers),
+    ~ c(list("drv" = purrr::pluck(drivers, .)), purrr::pluck(conn_args, .))
+  )
+
+  test_conns <- purrr::map(
+    test_conn_args,
+    ~ do.call(SCDB::get_connection, args = .)
+  )
+  names(test_conns) <- names(drivers)
+  test_conns <- purrr::discard(test_conns, is.null)
 
   # Skip backends if given
-  test_conns <- test_conns |>
-    purrr::walk(\(conn) {
-      if (checkmate::test_multi_class(conn, purrr::pluck(skip_backends, .default = ""))) {
-        DBI::dbDisconnect(conn)
+  test_conns <- purrr::walk(
+    test_conns,
+    ~ {
+      if (checkmate::test_multi_class(., purrr::pluck(skip_backends, .default = ""))) {
+        DBI::dbDisconnect(.)
       }
-    }) |>
-    purrr::discard(\(conn) checkmate::test_multi_class(conn, purrr::pluck(skip_backends, .default = "")))
+    }
+  )
+  test_conns <- purrr::discard(
+    test_conns,
+    ~ checkmate::test_multi_class(., purrr::pluck(skip_backends, .default = ""))
+  )
 
   # Run post_connect commands on the connections
-  purrr::walk2(test_conns, names(test_conns),
-               \(conn, conn_name) purrr::walk(purrr::pluck(conn_post_connect, conn_name), ~ DBI::dbExecute(conn, .)))
+  purrr::iwalk(
+    test_conns,
+    function(conn, conn_name) {
+      purrr::walk(purrr::pluck(conn_post_connect, conn_name), ~ DBI::dbExecute(conn, .))
+    }
+  )
 
   # Inform the user about the tested back ends:
   msg <- paste(sep = "\n",
@@ -141,12 +161,12 @@ get_test_conns <- function(skip_backends = NULL) {
 checkmate_err_msg <- function(expr) {
   tryCatch(
     expr,
-    error = \(e) {
-      e$message |>
-        stringr::str_remove_all(stringr::fixed("\n *")) |>
-        stringr::str_remove_all(stringr::fixed("* ")) |>
-        simpleError(message = _) |>
-        stop()
+    error = function(e) {
+      msg <- e$message
+      msg <- stringr::str_remove_all(msg, stringr::fixed("\n *"))
+      msg <- stringr::str_remove_all(msg, stringr::fixed("* "))
+
+      stop(simpleError(message = msg))                                                                                  # nolint: condition_call_linter
     }
   )
 }
